"""
Analytics will contain the following:
- cli for viewing snapsots of workflows and agents
- context simulator for testing workflows and agents
- metrics of the snapshot engine
- other analysis tools 
"""

from .context_explorer import ContextExplorer